/** <?php /**
 * @name PHPIDS
 * @uses http://php-ids.org/
 *
 * @author Stefanie Janine Stoelting, mail@stefanie-stoelting.de
 * @package PHPIDS
 * @license LGPL
 * @since 2009/08/28
 * @version 0.6.0.1
 *
 * <strong>0.6.0.1</strong> A plugin to include PHPIDS into MODx to log and prevent intrusions
 * First download PHPDS from its homepage and load it up to your webspace.
 * If you install PHPIDS into a public path, you should remove webaccess to the
 * lib path, for example with the attached .htaccess file.
 *
 * This plugin is based on an article published by Heise Verlag:
 * Getting started with the PHPIDS intrusion detection system
 * http://www.h-online.com/security/Getting-started-with-the-PHPIDS-intrusion-detection-system--/features/113163
 *
 * Requierments: MODx 0.9.6 or newer, PHP 5.1.2 or newer, PHPIDS 0.6
 *
 * On page Systemevents check the entry OnWebPagePrerender
 *
 * For database logging please create the table as defined IDS/Log/Database.php
 *
 * For a test just call your site with the following parameters: index.php?id=1&test=">XXX
 *
 * Snippet Properties
 *
 * &basePath=PHPIDS path?;string;assets/lib/phpids/lib &useLogFile=Use log file?;list;true,false;true &$useEmail=Use email?;list;true,false;true &useDatabase=Use database?;list;true,false;true
 *
 **/

$basePath     = isset($basePath)? $modx->config['base_path'] . $basePath:$modx->config['base_path'] . 'assets/lib/phpids/lib';
$useLogFile   = isset($useLogFile)? $useLogFile: true;
$useEmail     = isset($useEmail)? $useEmail: true;
$useDatabase  = isset($useDatabase)? $useDatabase: true;


set_include_path(
   get_include_path()
   . PATH_SEPARATOR
   . $basePath
  );


require_once 'IDS/Init.php';
try {
  $request = array(
    'REQUEST' => $_REQUEST,
  	'GET' => $_GET,
  	'POST' => $_POST,
  	'COOKIE' => $_COOKIE
  );

  $init = IDS_Init::init($basePath . '/IDS/Config/Config.ini');

  $init->config['General']['base_path'] = $basePath . '//IDS/';
  $init->config['General']['use_base_path'] = true;
  $init->config['Caching']['caching'] = 'none';

  $ids = new IDS_Monitor($request, $init);
  $result = $ids->run();

  if (!$result->isEmpty()) {

    require_once 'IDS/Log/Composite.php';

  	$compositeLog = new IDS_Log_Composite();

    if ($useLogFile) {

      require_once 'IDS/Log/File.php';
    	$compositeLog->addLogger(IDS_Log_File::getInstance($init));

    }

    if ($useEmail) {

      require_once 'IDS/Log/Email.php';
    	$compositeLog->addLogger(IDS_Log_Email::getInstance($init));

    }

    if ($useDatabase) {

      require_once 'IDS/Log/Database.php';
    	$compositeLog->addLogger(IDS_Log_Database::getInstance($init));

    }

   	$compositeLog->execute($result);
  }

} catch (Exception $e) {

  // Exeption is only shown, on backend login
  if (isset($_SESSION['mgrValidated'])? $_SESSION['mgrValidated']: false == 1) {
    printf( 'An error occured: %s', $e->getMessage());
  }

}
